//
//  ODY_NavigationBarShadow.m
//  导航栏渐变
//
//  Created by MuHao_NB on 16/8/1.
//  Copyright © 2016年 apple. All rights reserved.
//

#import "ODY_NavigationBarShadow.h"

@interface ODY_NavigationBarShadow ()
/**
 *  记录上次导航栏透明度
 */
@property (nonatomic, assign) float                 myalpha;
/**
 *  是否跳转
 */
@property (nonatomic, assign) BOOL                  isRouter;
/**
 *  颜色色值
 */
@property (nonatomic, assign) NSInteger             valueRGB;
@end

@implementation ODY_NavigationBarShadow
/**
 *  导航栏的颜色//FIGURE_COLOR
 */
- (void)shadowNavigationBar:(UIViewController *)viewController colorWithRGB:(NSInteger)valueRGB
{
    _valueRGB = valueRGB;
    [viewController.navigationController.navigationBar setBackgroundImage:[self imageWithBgColor:[UIColor colorWithRed:1 green:1 blue:1 alpha:0]] forBarMetrics:UIBarMetricsDefault];
    [viewController.navigationController.navigationBar setShadowImage:[self imageWithBgColor:[UIColor colorWithRed:1 green:1 blue:1 alpha:0]]];
}

- (UIImage *)imageWithBgColor:(UIColor *)color
{
    CGRect rect = CGRectMake(0.0f, 0.0f, 1.0f, 1.0f);
    UIGraphicsBeginImageContext(rect.size);
    CGContextRef context = UIGraphicsGetCurrentContext();
    CGContextSetFillColorWithColor(context, [color CGColor]);
    CGContextFillRect(context, rect);
    UIImage *image = UIGraphicsGetImageFromCurrentImageContext();
    UIGraphicsEndImageContext();
    return image;
}

- (void)enterWith:(UIViewController *)viewController
{
    if (self.myalpha >= 1.0)
    {
        self.myalpha = 0.8;
    }
    _isRouter = NO;
    [viewController.navigationController.navigationBar setBackgroundImage:[self imageWithBgColor:[self colorWithRGB:_valueRGB alpha:_myalpha]] forBarMetrics:UIBarMetricsDefault];
}

- (void)leaveWith:(UIViewController *)viewController
{
    _isRouter = YES;
    [viewController.navigationController.navigationBar setBackgroundImage:[self imageWithBgColor:WHITE_COLOR] forBarMetrics:UIBarMetricsDefault];
    viewController.navigationController.navigationBar.barTintColor = WHITE_COLOR;
    [viewController.navigationController.navigationBar setShadowImage:nil];
    viewController.navigationController.navigationBar.translucent = YES;
}

- (void)scrollToChangeShadowValueWith:(UIViewController *)viewController scrollView:(UIScrollView *)scrollView
{
    if (_isRouter == NO)
    {
        self.myalpha = scrollView.contentOffset.y / 300;
        if (self.myalpha >= 1.0)
        {
            self.myalpha = 0.8;
        }
        [viewController.navigationController.navigationBar setBackgroundImage:[self imageWithBgColor:[self colorWithRGB:_valueRGB alpha:_myalpha]] forBarMetrics:UIBarMetricsDefault];
    }
    viewController.navigationController.navigationBar.alpha = (64 + scrollView.contentOffset.y) / 64;
}

- (UIColor *)colorWithRGB:(NSUInteger)aRGB alpha:(CGFloat)alpha
{
    return [UIColor colorWithRed:((float)((aRGB & 0xFF0000) >> 16))/255.0 green:((float)((aRGB & 0xFF00) >> 8))/255.0 blue:((float)(aRGB & 0xFF))/255.0 alpha:alpha];
}
@end
